% create_signal.m
%
% This script creates a synthetic a post-seismic relaxation signal to test it.
%
% 26/10/2015 Machiel Bos, Santa Clara
%===============================================================================

  clear all;

  n=5000;
  MJD0 = 51544.0; 
  t=linspace(1,n,n)';
  x=zeros(n,1);
  
  V              = 0.02/365.25;  % vertical velocity
  offsets        = [450.0,3;2000,-2;3500.0,1];
  postseismiclog = [450.0,10.0;3500.0,10.0];
  postseismicexp = [2000.0,100.0];

  %--- Write header
  fp = fopen('TEST.mom','w');
  fprintf(fp,'# sampling period 1.0\n');
  for i=1:3
    fprintf(fp,'# offset %8.1f\n',offsets(i)+MJD0);
  end
  for i=1:2
    fprintf(fp,'# log %8.1f %6.1f\n',postseismiclog(i,1)+MJD0,...
							postseismiclog(i,2));
  end
  for i=1:1
    fprintf(fp,'# exp %8.1f %6.1f\n',postseismicexp(i,1)+MJD0,...
							postseismicexp(i,2));
  end

  %--- Create power-law + white noise
  alpha    = 1.0;
  sigma_pl = 0.1;
  sigma_w  = 0.05;
  h = zeros(n,1);
  h(1) = 1;
  for i=2:n
    tau = i-1;
    h(i) = (alpha/2+tau-1)*h(i-1)/tau;
  end
  w1 = sigma_pl*randn(n,1);
  w2 = sigma_w*randn(n,1);
  x  = fftconv(h,w1)(1:n) + w2;

  %--- uplift
  x += V*t;

  %--- Offsets
  for i=1:n
    for j=1:3
      if i>offsets(j,1)
        x(i) += offsets(j,2);
      end
    end
  end
    
  %--- Post-seismic logarithmic relaxation
  for j=1:2
    z = zeros(n,1);
    for i=1:n
      if i>postseismiclog(j,1)
        if j==1
          z(i) =  2.0e-1*log(1 + (i-postseismiclog(j,1))/postseismiclog(j,2));
        else 
	  z(i) = -3.0e-1*log(1 + (i-postseismiclog(j,1))/postseismiclog(j,2));
        end
      end
    end
    x += z;
  end
    
  %--- Post-seismic exponential relaxation
  z = zeros(n,1);
  for i=1:n
    if i>postseismicexp(1,1)
      z(i) = 1.0*(1.0 - exp(-(i-postseismicexp(1,1))/postseismicexp(1,2)));
    end
  end
  x += z;

  %--- Save signal to file
  for i=1:n
    fprintf(fp,'%8.1f %7.3f\n',t(i)+MJD0,x(i));
  end 
  fclose(fp);

  %--- Make plot
  figure(1)
  plot(t,x,'b-');
