/*! \file    EstimateTrend.cpp
 *  \author  Machiel Bos
 *
 * This program estimates a trend from the observations.
 *
 *  This script is part of Hector 2.1
 *
 *  Hector is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  Hector is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Hector. If not, see <http://www.gnu.org/licenses/>
 *
 */
//=============================================================================
  #include "Minimizer.h"
  #include "JSON.h"
  #include <iostream>
  #include <ostream>
  #include <cstdlib>
  #include <ctime>

//=============================================================================
// Main program
//=============================================================================

  int main(int argc, char *argv[])
  {

    using namespace std;
    //--- Open correct control file
    if (argc==1) {
      Control &control = Control::getInstance("estimatetrend.ctl");
    } else if (argc==2) {
      Control &control = Control::getInstance(argv[1]);
    } else {
      cerr << "correct usage: estimatetrend [controlfile.ctl]" << endl;
      exit(EXIT_FAILURE);
    }

    //--- JSON class instance
    JSON    &json = JSON::getInstance("estimatetrend.json");

    //--- Start estimatetrend
    cout << endl 
         << "************************************" << endl 
         << "    estimatetrend, version " << VERSION << endl
         << "************************************" << endl;

    Minimizer      minimizer;
    time_t         start,end;

    time(&start);
    minimizer.solve();
    time(&end);
    cout << "Total computing time: " << difftime(end,start) << " sec" << endl;

    //--- DesignMatrix is not a Meyer singleton so delete manually
    DesignMatrix   *designmatrix=DesignMatrix::getInstance();
    designmatrix->resetInstance();

    return EXIT_SUCCESS;
  }
